@@ -16,9 +16,9 @@
 
 double op_cpu_frequency(void)
 {
-	double fval;
+	double fval = 0.0;
 	unsigned long uval;
-	char * line;
+	char * line = NULL;
 
 	FILE * fp = op_try_open_file("/proc/cpuinfo", "r");
 	if (!fp)
@@ -37,21 +37,28 @@ double op_cpu_frequency(void)
 
 		/* x86/parisc/ia64/x86_64 */
 		if (sscanf(line, "cpu MHz : %lf", &fval) == 1)
-			return fval;
+			break;
 		/* ppc/ppc64 */
 		if (sscanf(line, "clock : %lfMHz", &fval) == 1)
-			return fval;
+			break;
 		/* alpha */
-		if (sscanf(line, "cycle frequency [Hz] : %lu", &uval) == 1)
-			return uval / 1E6;
+		if (sscanf(line, "cycle frequency [Hz] : %lu", &uval) == 1) {
+			fval = uval / 1E6;
+			break;
+		}
 		/* sparc64 if CONFIG_SMP only */
-		if (sscanf(line, "Cpu0ClkTck : %lx", &uval) == 1)
-			return uval / 1E6;
+		if (sscanf(line, "Cpu0ClkTck : %lx", &uval) == 1) {
+			fval = uval / 1E6;
+			break;
+		}
+		/* s390 doesn't provide cpu freq, checked up to 2.6-test4 */
 
 		free(line);
 	}
 
+	if (line)
+		free(line);
 	op_close_file(fp);
 
-	return 0.0;
+	return fval;
 }
