@@ -15,31 +15,26 @@
 #include <string>
 #include <vector>
 
-#include "utility.h"
 #include "common_option.h"
-#include "string_filter.h"
 #include "path_filter.h"
 
-class partition_files;
+class profile_classes;
 
 namespace options {
-	extern bool demangle;
-	extern bool smart_demangle;
+	extern demangle_type demangle;
 	extern bool source;
 	extern bool assembly;
 	extern string_filter symbol_filter;
 	extern path_filter file_filter;
 	extern std::string output_dir;
-	extern std::string source_dir;
+	extern std::vector<std::string> search_dirs;
+	extern std::vector<std::string> base_dirs;
 	extern std::vector<std::string> objdump_params;
 	extern double threshold;
 }
 
-/**
- * a partition of sample filename to treat, each sub-list is a list of
- * sample to merge. filled by handle_options()
- */
-extern scoped_ptr<partition_files> sample_file_partition;
+/// classes of sample filenames to handle
+extern profile_classes classes;
 
 /**
  * handle_options - process command line
